############################################################
## Download data
## Download files of 10 samples for each sample group
## (uses: https://github.com/axel-download-accelerator/axel)
############################################################
if (!all(file.exists("data.txt", "qa.rda"))) {
rnaseqdata <- read.delim2("http://www.ebi.ac.uk/arrayexpress/files/E-GEUV-1/E-GEUV-1.sdrf.txt",
                          stringsAsFactors = FALSE)
rnaseqdata <- rnaseqdata[, c("Factor.Value.population.", "Comment.FASTQ_URI.")]
names(rnaseqdata) <- c("group", "url")

downloadFiles <- function(fastq_url) {
    lapply(fastq_url, function(url) {
        if (file.exists(basename(url)))
            print(paste("File", basename(url), "exists."))
        else
            system2("axel", c("-a", "-n", 20, url), NULL, NULL)
    })
}

subsetData <- function(data, group, n = NULL) {
    data.subset <- data[data$group == group, ]
    if (is.null(n))
        data.subset
    else
        data.subset[1:n, ]
}

groups <- names(table(rnaseqdata$group))
invisible(lapply(groups, function(group) {
    print(paste("Group", group))
    data.group <- subsetData(rnaseqdata, group, 10)
    downloadFiles(data.group$url)
}))
rnaseqdata$filename <- basename(rnaseqdata$url)
data <- rnaseqdata[file.exists(rnaseqdata$filename), ]
write.table(data, "data.txt", row.names = FALSE, sep = "\t")
}

############################################################
## Section 3 - install Rqc
############################################################
if (!require("Rqc")) {
    source("https://bioconductor.org/biocLite.R")
    biocLite("Rqc")
}

############################################################
## Section 3 - load Rqc and data
## Results are loaded from 'qa.rda' file by default.
############################################################
library("Rqc")
data <- read.delim2("data.txt", stringsAsFactors = FALSE)
files <- data$filename
pair <- rep(1:25, each = 2)
group <- factor(data$group)
checkpoint("qa", path = ".", {
    qa <- rqcQA(files, pair = pair, group = group, workers = 4)
}, keep = "qa")
qa[1]

############################################################
## Section 3.1 - file information of FASTQ files
############################################################
library("xtable")
fileInformation <- perFileInformation(qa)
fileInformation$path <- NULL
index <- c(1, 2, 11, 12, 21, 22, 31, 32, 41, 42)
fileInformation[index, ]

############################################################
## Section 3.2 - read quality box plot
############################################################
rqcReadQualityBoxPlot(qa[index]) + scale_fill_brewer(palette = "Set1")

############################################################
## Section 3.2 - subset by group and file pair
############################################################
qa.ceu <- subsetByGroup(qa, "CEU")
qa.pair1 <- subsetByPair(qa, 1)

############################################################
## Section 3.2 - read-specific quality plot
############################################################
rqcReadQualityPlot(qa.pair1) + scale_color_brewer(palette = "Set1")

############################################################
## Section 3.2 - cycle-specific quality biplot
############################################################
rqcCycleAverageQualityPcaPlot(qa.pair1) + theme_bw()

############################################################
## Section 3.2 - cycle-specific average quality plot
############################################################
rqcCycleAverageQualityPlot(qa.pair1) + scale_color_brewer(palette = "Set1")

############################################################
## Section 3.2 - cycle-specific quality distribution plot
############################################################
rqcCycleQualityPlot(qa.pair1)

############################################################
## Section 3.2 - file-specific top overrepresented reads heatmap
############################################################
rqcFileHeatmap(qa[[1]])

############################################################
## Section 3.2 - cycle-specific base calls plot
############################################################
rqcCycleBaseCallsLinePlot(qa[[1]])

############################################################
## Section 3.3 - report
############################################################
rqcReport(qa, outdir = ".", file = "qa_report")

############################################################
## Section 3.3 - interactive report
############################################################
if (interactive())
    rqcShinyReport(qa)

############################################################
## Section 5 - session information
############################################################
sessionInfo()

